@@ -48,5 +48,16 @@ test_that("get_uk_regional_cases returns correct numbers of regions", {
   adm_2_data <- get_uk_regional_cases_with_level_2()
   
   expect_equal(length(unique(na.omit(adm_1_data$region_level_1))), 13)
-  expect_gt(length(unique(na.omit(adm_2_data$region_level_2))), 200)
+  expect_gt(length(unique(na.omit(adm_2_data$region_level_2))), 20)
+})
+
+test_that("get_uk_regional_cases returns data by date of release", {
+  adm_1_data <- get_uk_regional_cases_only_level_1(release_date = "2020-09-01")
+  nhsregions_data <- get_uk_regional_cases_only_level_1(release_date = Sys.Date() - 13, 
+                                                        nhsregions = TRUE)
+  adm_2_data <- get_uk_regional_cases_with_level_2(release_date = "2020-09-01")
+  expect_equal(max(adm_1_data$date), as.Date("2020-09-01"))
+  expect_equal(max(nhsregions_data$date), Sys.Date() - 13)
+  expect_equal(max(adm_2_data$date), as.Date("2020-09-01"))
+  expect_error(get_uk_regional_cases_only_level_1(release_date = "2020-11-01", nhsregions = TRUE))
 })
